@@ -15,10 +15,7 @@ import warnings
 from stripe._api_version import _ApiVersion
 from stripe._api_requestor import _APIRequestor
 
-# We must import the app_info module early to populate it into
-# `sys.modules`; otherwise doing `import stripe.app_info` will end up
-# importing that module, and not the global `AppInfo` name from below.
-import stripe.app_info
+
 from stripe._app_info import AppInfo as AppInfo
 from stripe._version import VERSION as VERSION
 
@@ -100,8 +97,6 @@ from stripe._webhook import (
 # StripeClient
 from stripe._stripe_client import StripeClient as StripeClient  # noqa
 
-from stripe.v2._event import ThinEvent as ThinEvent  # noqa
-
 
 # Sets some basic information about the running application that's sent along
 # with API requests. Useful for plugin authors to identify their plugin when
@@ -133,6 +128,7 @@ from stripe._search_result_object import (
 )
 from stripe._stripe_object import StripeObject as StripeObject
 from stripe._request_options import RequestOptions as RequestOptions
+from stripe._stripe_context import StripeContext as StripeContext
 from stripe._createable_api_resource import (
     CreateableAPIResource as CreateableAPIResource,
 )
@@ -204,52 +200,13 @@ from stripe._http_client import (
     UrlFetchClient as UrlFetchClient,
     HTTPXClient as HTTPXClient,
     AIOHTTPClient as AIOHTTPClient,
+    UrllibClient as UrllibClient,
     new_default_http_client as new_default_http_client,
 )
 
 # Util
 from stripe._util import convert_to_stripe_object as convert_to_stripe_object
 
-# Backwards compatibility re-exports
-if not TYPE_CHECKING:
-    from stripe import _stripe_response as stripe_response
-    from stripe import _stripe_object as stripe_object
-    from stripe import _error_object as error_object
-    from stripe import _error as error
-    from stripe import _http_client as http_client
-    from stripe import _util as util
-    from stripe import _oauth as oauth
-    from stripe import _webhook as webhook
-    from stripe import _multipart_data_generator as multipart_data_generator
-    from stripe import _request_metrics as request_metrics
-    from stripe._file import File as FileUpload
-
-    # Python 3.7+ supports module level __getattr__ that allows us to lazy load deprecated modules
-    # this matters because if we pre-load all modules from api_resources while suppressing warning
-    # users will never see those warnings
-    if _sys.version_info[:2] >= (3, 7):
-
-        def __getattr__(name):
-            if name == "abstract":
-                import stripe.api_resources.abstract as _abstract
-
-                return _abstract
-            if name == "api_resources":
-                import stripe.api_resources as _api_resources
-
-                return _api_resources
-            raise AttributeError(
-                f"module {__name__!r} has no attribute {name!r}"
-            )
-
-    else:
-        with warnings.catch_warnings():
-            warnings.filterwarnings("ignore", category=DeprecationWarning)
-
-            import stripe.api_resources.abstract as abstract
-            import stripe.api_resources as api_resources
-
-
 # API resources
 
 # The beginning of the section generated from our OpenAPI spec
@@ -265,6 +222,7 @@ from stripe import (
     forwarding as forwarding,
     identity as identity,
     issuing as issuing,
+    params as params,
     radar as radar,
     reporting as reporting,
     sigma as sigma,
@@ -314,6 +272,10 @@ from stripe._application_fee_service import (
 from stripe._apps_service import AppsService as AppsService
 from stripe._balance import Balance as Balance
 from stripe._balance_service import BalanceService as BalanceService
+from stripe._balance_settings import BalanceSettings as BalanceSettings
+from stripe._balance_settings_service import (
+    BalanceSettingsService as BalanceSettingsService,
+)
 from stripe._balance_transaction import (
     BalanceTransaction as BalanceTransaction,
 )
