@@ -1,22 +1,21 @@
-from __future__ import absolute_import, division, print_function
-
 import atexit
 import os
 import sys
-from distutils.version import StrictVersion
-
 import pytest
 
 import stripe
-from stripe.six.moves.urllib.request import urlopen
-from stripe.six.moves.urllib.error import HTTPError
+from stripe import StripeClient
+import requests
 
-from tests.request_mock import RequestMock
 from tests.stripe_mock import StripeMock
+from tests.http_client_mock import HTTPClientMock
+from stripe._http_client import new_default_http_client
 
 
-# When changing this number, don't forget to change it in `.travis.yml` too.
-MOCK_MINIMUM_VERSION = "0.105.0"
+pytest_plugins = ("anyio",)
+
+
+MOCK_MINIMUM_VERSION = "0.109.0"
 
 # Starts stripe-mock if an OpenAPI spec override is found in `openapi/`, and
 # otherwise fall back to `STRIPE_MOCK_PORT` or 12111.
@@ -25,6 +24,9 @@ if StripeMock.start():
 else:
     MOCK_PORT = os.environ.get("STRIPE_MOCK_PORT", 12111)
 
+MOCK_API_BASE = "http://localhost:%s" % MOCK_PORT
+MOCK_API_KEY = "sk_test_123"
+
 
 @atexit.register
 def stop_stripe_mock():
@@ -34,21 +36,7 @@ def stop_stripe_mock():
 def pytest_configure(config):
     if not config.getoption("--nomock"):
         try:
-            resp = urlopen("http://localhost:%s/" % MOCK_PORT)
-            info = resp.info()
-            version = info.get("Stripe-Mock-Version")
-            if version != "master" and StrictVersion(version) < StrictVersion(
-                MOCK_MINIMUM_VERSION
-            ):
-                sys.exit(
-                    "Your version of stripe-mock (%s) is too old. The minimum "
-                    "version to run this test suite is %s. Please "
-                    "see its repository for upgrade instructions."
-                    % (version, MOCK_MINIMUM_VERSION)
-                )
-
-        except HTTPError as e:
-            info = e.info()
+            requests.get("http://localhost:%s/" % MOCK_PORT)
         except Exception:
             sys.exit(
                 "Couldn't reach stripe-mock at `localhost:%s`. Is "
@@ -66,7 +54,7 @@ def pytest_addoption(parser):
 
 
 def pytest_runtest_setup(item):
-    if "request_mock" in item.fixturenames and item.config.getoption(
+    if "http_client_mock" in item.fixturenames and item.config.getoption(
         "--nomock"
     ):
         pytest.skip(
@@ -78,23 +66,48 @@ def pytest_runtest_setup(item):
 def setup_stripe():
     orig_attrs = {
         "api_base": stripe.api_base,
+        "upload_api_base": stripe.upload_api_base,
         "api_key": stripe.api_key,
         "client_id": stripe.client_id,
         "default_http_client": stripe.default_http_client,
     }
-    http_client = stripe.http_client.new_default_http_client()
-    stripe.api_base = "http://localhost:%s" % MOCK_PORT
-    stripe.api_key = "sk_test_123"
+    http_client = new_default_http_client()
+    stripe.api_base = MOCK_API_BASE
+    stripe.upload_api_base = MOCK_API_BASE
+    stripe.api_key = MOCK_API_KEY
     stripe.client_id = "ca_123"
     stripe.default_http_client = http_client
     yield
     http_client.close()
     stripe.api_base = orig_attrs["api_base"]
+    stripe.upload_api_base = orig_attrs["upload_api_base"]
     stripe.api_key = orig_attrs["api_key"]
     stripe.client_id = orig_attrs["client_id"]
     stripe.default_http_client = orig_attrs["default_http_client"]
 
 
 @pytest.fixture
-def request_mock(mocker):
-    return RequestMock(mocker)
+def http_client_mock(mocker):
+    mock_client = HTTPClientMock(mocker)
+    old_client = stripe.default_http_client
+    stripe.default_http_client = mock_client.get_mock_http_client()
+    yield mock_client
+    stripe.default_http_client = old_client
+
+
+@pytest.fixture
+def stripe_mock_stripe_client(http_client_mock):
+    return StripeClient(
+        MOCK_API_KEY,
+        base_addresses={"api": MOCK_API_BASE},
+        http_client=http_client_mock.get_mock_http_client(),
+    )
+
+
+@pytest.fixture
+def file_stripe_mock_stripe_client(http_client_mock):
+    return StripeClient(
+        MOCK_API_KEY,
+        base_addresses={"files": MOCK_API_BASE},
+        http_client=http_client_mock.get_mock_http_client(),
+    )
